@@ -1,5 +1,6 @@
 import os
-from typing import Callable, List, Dict, Iterable, Sequence, Union, Any, Tuple
+from os.path import dirname, abspath
+from typing import Callable, List, Dict, Iterable, Sequence, Union, Any
 
 import numpy
 import numpy as np
@@ -290,4 +291,14 @@ def as_list(*args, **kwargs) -> list:
         >>> as_list(1, 2, 3, 4, key=5)
         [1, 2, 3, 4, 5]
     """
-    return list(args) + list(kwargs.values())
\ No newline at end of file
+    return list(args) + list(kwargs.values())
+
+
+def tensorneko_path() -> str:
+    """
+    Get the `tensorneko` library root path
+
+    Returns:
+        ``str``: The root path of `tensorneko`
+    """
+    return dirname(dirname(abspath(__file__)))
